==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/waf/kotlin/inputs/WebAclLoggingConfigurationRedactedFieldsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.waf.kotlin.inputs

import com.pulumi.aws.waf.inputs.WebAclLoggingConfigurationRedactedFieldsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property fieldToMatches Set of configuration blocks for fields to redact. Detailed below.
 */
public data class WebAclLoggingConfigurationRedactedFieldsArgs(
    public val fieldToMatches: Output<List<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>>,
) : ConvertibleToJava<com.pulumi.aws.waf.inputs.WebAclLoggingConfigurationRedactedFieldsArgs> {
    override fun toJava(): com.pulumi.aws.waf.inputs.WebAclLoggingConfigurationRedactedFieldsArgs =
        com.pulumi.aws.waf.inputs.WebAclLoggingConfigurationRedactedFieldsArgs.builder()
            .fieldToMatches(
                fieldToMatches.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WebAclLoggingConfigurationRedactedFieldsArgs].
 */
@PulumiTagMarker
public class WebAclLoggingConfigurationRedactedFieldsArgsBuilder internal constructor() {
    private var fieldToMatches:
        Output<List<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>>? = null

    /**
     * @param value Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("vfynbugrswyvjvov")
    public suspend
    fun fieldToMatches(`value`: Output<List<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>>) {
        this.fieldToMatches = value
    }

    @JvmName("kxnhddwhodmehyec")
    public suspend fun fieldToMatches(
        vararg
        values: Output<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>,
    ) {
        this.fieldToMatches = Output.all(values.asList())
    }

    /**
     * @param values Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("pexdkqnapnbiqxra")
    public suspend
    fun fieldToMatches(values: List<Output<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>>) {
        this.fieldToMatches = Output.all(values)
    }

    /**
     * @param value Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("qqvytmhjlyhqdutq")
    public suspend
    fun fieldToMatches(`value`: List<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fieldToMatches = mapped
    }

    /**
     * @param argument Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("jnstrbbujloxhbja")
    public suspend
    fun fieldToMatches(argument: List<suspend WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.fieldToMatches = mapped
    }

    /**
     * @param argument Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("opccxgnnueumesnv")
    public suspend fun fieldToMatches(
        vararg
        argument: suspend WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.fieldToMatches = mapped
    }

    /**
     * @param argument Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("rfbsxabmsbajyglt")
    public suspend
    fun fieldToMatches(argument: suspend WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.fieldToMatches = mapped
    }

    /**
     * @param values Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("nfygoynkyefgxkda")
    public suspend fun fieldToMatches(
        vararg
        values: WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fieldToMatches = mapped
    }

    internal fun build(): WebAclLoggingConfigurationRedactedFieldsArgs =
        WebAclLoggingConfigurationRedactedFieldsArgs(
            fieldToMatches = fieldToMatches ?: throw PulumiNullFieldException("fieldToMatches"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/waf/kotlin/inputs/WebAclLoggingConfigurationRedactedFieldsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.waf.kotlin.inputs

import com.pulumi.aws.waf.inputs.WebAclLoggingConfigurationRedactedFieldsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property fieldToMatches Set of configuration blocks for fields to redact. Detailed below.
 */
public data class WebAclLoggingConfigurationRedactedFieldsArgs(
    public val fieldToMatches: Output<List<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>>,
) : ConvertibleToJava<com.pulumi.aws.waf.inputs.WebAclLoggingConfigurationRedactedFieldsArgs> {
    override fun toJava(): com.pulumi.aws.waf.inputs.WebAclLoggingConfigurationRedactedFieldsArgs =
        com.pulumi.aws.waf.inputs.WebAclLoggingConfigurationRedactedFieldsArgs.builder()
            .fieldToMatches(
                fieldToMatches.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WebAclLoggingConfigurationRedactedFieldsArgs].
 */
@PulumiTagMarker
public class WebAclLoggingConfigurationRedactedFieldsArgsBuilder internal constructor() {
    private var fieldToMatches:
        Output<List<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>>? = null

    /**
     * @param value Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("kqromngahjarxowx")
    public suspend fun fieldToMatches(`value`: Output<List<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>>) {
        this.fieldToMatches = value
    }

    @JvmName("dryqqexybjsoctsq")
    public suspend fun fieldToMatches(vararg values: Output<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>) {
        this.fieldToMatches = Output.all(values.asList())
    }

    /**
     * @param values Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("wuymotcqxilmjmgg")
    public suspend fun fieldToMatches(values: List<Output<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>>) {
        this.fieldToMatches = Output.all(values)
    }

    /**
     * @param value Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("nhdhucgnbjxgdipr")
    public suspend fun fieldToMatches(`value`: List<WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fieldToMatches = mapped
    }

    /**
     * @param argument Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("nbtgrkhfeefymecq")
    public suspend fun fieldToMatches(argument: List<suspend WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.fieldToMatches = mapped
    }

    /**
     * @param argument Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("kanguobrpxcnqdsj")
    public suspend fun fieldToMatches(vararg argument: suspend WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.fieldToMatches = mapped
    }

    /**
     * @param argument Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("ctqptoysvxfikvsb")
    public suspend fun fieldToMatches(argument: suspend WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.fieldToMatches = mapped
    }

    /**
     * @param values Set of configuration blocks for fields to redact. Detailed below.
     */
    @JvmName("fvalthwiylkgwxut")
    public suspend fun fieldToMatches(vararg values: WebAclLoggingConfigurationRedactedFieldsFieldToMatchArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fieldToMatches = mapped
    }

    internal fun build(): WebAclLoggingConfigurationRedactedFieldsArgs =
        WebAclLoggingConfigurationRedactedFieldsArgs(
            fieldToMatches = fieldToMatches ?: throw PulumiNullFieldException("fieldToMatches"),
        )
}
